@@ -1,7 +1,10 @@
 "template automatic tests"
+import os
 import os.path as osp
 from cubicweb.devtools import testlib
 
+os.environ['HGRCPATH'] = os.devnull
+
 class AutomaticWebTest(testlib.AutomaticWebTest):
     no_auto_populate = ('Repository', 'Revision')
     ignored_relations = set(('parent_revision',
